<?php

namespace Drupal\layout_builder_enhancements\EventSubscriber;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Drupal\layout_builder_enhancements\Plugin\Block\ViewBlock;
use Drupal\layout_builder\LayoutBuilderEvents;
use Drupal\layout_builder\Event\SectionComponentBuildRenderArrayEvent;
use function Drupal\facets\Plugin\facets\url_processor\drupal_static;

/**
 * EventSubscriber for layout render event.
 */
class ViewEventSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      LayoutBuilderEvents::SECTION_COMPONENT_BUILD_RENDER_ARRAY => [
        'onBuildRender',
        100,
      ],
    ];
  }

  /**
   * Event render function.
   */
  public function onBuildRender(SectionComponentBuildRenderArrayEvent $event) {
    $block = $event->getPlugin();
    if (!$block instanceof ViewBlock) {
      return;
    }
    $build = $event->getBuild();
    $offset = $this->getOffset($block->getDerivativeId());
    $block->setOffset($offset);
    $block->inPreview($event->inPreview());
    $build['content'] = $block->build();
    $event->setBuild($build);
  }

  protected function getOffset($id) {
    $offset =& \drupal_static(__FUNCTION__);
    if (!$offset) {
      $offset = [];
    }
    if (!isset($offset[$id])) {
      $offset[$id] = -1;
    }
    $offset[$id]++;
    return $offset[$id];
  }

}
